@@ -40,7 +40,7 @@
 
 // Constructor for the theme manager
 ThemeManager::ThemeManager(const QString &themefile, QObject* parent, int initialSize)
-    : QObject(parent), mRenderer(0), mConfig( 0 )
+    : QObject(parent), mRenderer(), mConfig()
 {
   mScale            = initialSize;
   mAspectRatio      = 1.0;
@@ -73,7 +73,7 @@ void ThemeManager::unregisterTheme(Themeable* ob)
 int ThemeManager::checkTheme()
 {
   // Check theme
-  if (mRenderer == 0) return 1;
+  if (mRenderer == nullptr) return 1;
   return 0; // Ok
 }
 
@@ -113,9 +113,9 @@ void ThemeManager::updateTheme(const QString &themefile)
   qCDebug(KFOURINLINE_LOG) << "Reading SVG master file  =" << svgfile;
   mAspectRatio     =  config(QStringLiteral("general")).readEntry("aspect-ratio", 1.0);
   qCDebug(KFOURINLINE_LOG) << "Aspect ratio =" << mAspectRatio;
-  mColorNamePlayer[0] = i18nc("Player 0 color", config(QStringLiteral("general")).readEntry("colorNamePlayer0").toUtf8());
+  mColorNamePlayer[0] = i18nc("Player 0 color", config(QStringLiteral("general")).readEntry("colorNamePlayer0").toUtf8().constData());
   qCDebug(KFOURINLINE_LOG) << "Player 0 color name =" << mColorNamePlayer[0];
-  mColorNamePlayer[1] = i18nc("Player 1 color", config(QStringLiteral("general")).readEntry("colorNamePlayer1").toUtf8());
+  mColorNamePlayer[1] = i18nc("Player 1 color", config(QStringLiteral("general")).readEntry("colorNamePlayer1").toUtf8().constData());
   qCDebug(KFOURINLINE_LOG) << "Player 1 color name =" << mColorNamePlayer[1];
 
   delete mRenderer;
@@ -124,7 +124,7 @@ void ThemeManager::updateTheme(const QString &themefile)
   if (!result)
   {
     delete mRenderer;
-    mRenderer = 0;
+    mRenderer = nullptr;
     qCCritical(KFOURINLINE_LOG) << "Cannot open file" << svgfile;
   }
   qCDebug(KFOURINLINE_LOG) << "Renderer" << mRenderer<<" =" << result;
@@ -147,7 +147,7 @@ void ThemeManager::rescale(int scale, QPoint offset)
   if (global_debug > 1)
   {
     if (scale==mScale)
-      qCDebug(KFOURINLINE_LOG) <<" No scale change to" << scale << ". If this happends too often it is BAD";
+      qCDebug(KFOURINLINE_LOG) <<" No scale change to" << scale << ". If this happens too often it is BAD";
   }
   //if (scale==mScale) return;
   mScale = scale;
@@ -244,12 +244,12 @@ const QPixmap ThemeManager::getPixmap(const QString &svgid, const QString &svgre
 Themeable::Themeable()
 {
   mScale        = 1.0;
-  mThemeManager = 0;
+  mThemeManager = nullptr;
 }
 
 
 // Constructs a themeable interface given its id and the master theme manager.
-// This automatically registeres the object with the manager.
+// This automatically registers the object with the manager.
 Themeable::Themeable(const QString &id, ThemeManager* thememanager)
 {
   mScale        = 1.0;
